function [wChoquistic V1 V2 gamma bias] = getChoquistic2(instances, labels, rParameter)
%% Choquistic Regression for k=2 (2-way Interaction) 
% getChoquistic2(instances, labels, rParameter)
%
% It computes the Moebius transform for classification problem
%              - Instances 
%                is a matrix of instances without their labels
%              - labels 
%                is a vector (n x 1) contains of classes of instances
%              - rParameter 
%                is regularization parameter (L_1 regularization)
%
% The attributes are normalized between [0,1] and the directions
% are monotone. More -> Better
% The classes are 0 & 1
%
% It gives 
%              - wChoquistic
%                contains weights of convex form.
%              - V1
%                contains the values of moebius transform for single variables
%              - V2 
%                contains the values of moebius transform for 2 variables jointly
%              - gamma 
%			     precision parameter
%			   - bias
%                intercept parameter
%
% Author: Ali Fallah Tehrani (2013)
%         Philipps University Marburg
%         Computational Intelligence Group
%
%% Data Processing
format('short');
column = size(instances,2); 
[data] = getData(instances);
%% Choquistic Regression
V2=zeros(column,column);
% Computing Log Likelihood Function
fun = @(W)-getLogLikelihood(W(column^2 + 1), labels, W(1:(column)^2), data, W(column^2+2), rParameter);
lb = [zeros(1, column^2), 1e-6, 1e-10];
ub = [ones(1,column^2), inf, 1];
w0 = [(1/column^2)*ones(1, column^2), 0, 1e-5];
Aeq = [ones(1,(column)^2), 0, 0];
% finding parameters by maximum likelihood approach
optionesC = optimset( ...
    'LargeScale','on', ...
    'MaxFunEvals',1e5, ...
    'MaxIter',1e10, ...
    'Display','iter', ...
    'Algorithm','sqp' ...
);
[wChoquistic] = fmincon(fun, w0, [], [], Aeq, 1, lb, ub,[], optionesC);
[mobVector  ~] = getInteraction (wChoquistic);
V1 = mobVector(1:column);
V = mobVector(1+column:end);
V2(tril(true(column),-1)) = V;
V2 = V2 + V2';
gamma = wChoquistic(1,column^2 +1);
bias = wChoquistic(1,column^2 +2);


